==> statet-consoleserver-incubation-4.0.2-201910101100-r.tar.gz: NOTICE.md <==
# Notices for Eclipse StatET - RJ Server Tools

This content is produced and maintained by the Eclipse StatET project.

  * Project home: https://projects.eclipse.org/projects/science.statet


## Trademarks

Eclipse StatET, and StatET are trademarks of the Eclipse Foundation.


## Copyright

All content is the property of the respective authors or their employers. For
more information regarding authorship of content, please consult the listed
source code repository logs.


## Declared Project Licenses

This program and the accompanying materials are made available under the
terms of the Eclipse Public License 2.0 which is available at
https://www.eclipse.org/legal/epl-2.0, or the Apache License, Version 2.0
which is available at https://www.apache.org/licenses/LICENSE-2.0.

SPDX-License-Identifier: EPL-2.0 OR Apache-2.0


## Source Code

The project maintains the following source code repositories:

  * https://git.eclipse.org/c/statet/org.eclipse.statet.git
  * https://git.eclipse.org/c/statet/org.eclipse.statet-commons.git
  * https://git.eclipse.org/c/statet/org.eclipse.statet-docmlet.git
  * https://git.eclipse.org/c/statet/org.eclipse.statet-eutils.git
  * https://git.eclipse.org/c/statet/org.eclipse.statet-ltk.git
  * https://git.eclipse.org/c/statet/org.eclipse.statet-r.git
  * https://git.eclipse.org/c/statet/org.eclipse.statet-rj.git


## Third-party Content

This distribution artifact ("RJ Server Tools") leverages the following third party content:


## Cryptography

Content may contain encryption software. The country in which you are currently
may have restrictions on the import, possession, and use, and/or re-export to
another country, of encryption software. BEFORE using any encryption software,
please check the country's laws, regulations and policies concerning the import,
possession, or use, and re-export of encryption software, to see if this is
permitted.

==> statet-consoleserver-incubation-4.9.0-202402220600-r.tar.gz: NOTICE.md <==
# Notices for Eclipse StatET - RJ Server Tools

This content is produced and maintained by the Eclipse StatET project.

  * Project home: https://projects.eclipse.org/projects/science.statet


## Trademarks

Eclipse StatET, and StatET are trademarks of the Eclipse Foundation.


## Copyright

All content is the property of the respective authors or their employers. For
more information regarding authorship of content, please consult the listed
source code repository logs.


## Declared Project Licenses

This program and the accompanying materials are made available under the
terms of the Eclipse Public License 2.0 which is available at
https://www.eclipse.org/legal/epl-2.0, or the Apache License, Version 2.0
which is available at https://www.apache.org/licenses/LICENSE-2.0.

SPDX-License-Identifier: EPL-2.0 OR Apache-2.0


## Source Code

The project maintains the following source code repositories:

  * https://gitlab.eclipse.org/eclipse/statet/statet


## Third-party Content

This distribution artifact ("RJ Server Tools") leverages the following third party content:


## Cryptography

Content may contain encryption software. The country in which you are currently
may have restrictions on the import, possession, and use, and/or re-export to
another country, of encryption software. BEFORE using any encryption software,
please check the country's laws, regulations and policies concerning the import,
possession, or use, and re-export of encryption software, to see if this is
permitted.
